@@ -159,6 +159,8 @@ fn get_bucket_name(url: &Url) -> Result<&str> {
 
 #[cfg(test)]
 mod tests {
+    use super::*;
+    use datafusion::common::plan_err;
     use datafusion::{
         datasource::listing::ListingTableUrl,
         logical_expr::{DdlStatement, LogicalPlan},
@@ -166,8 +168,6 @@ mod tests {
     };
     use object_store::{aws::AmazonS3ConfigKey, gcp::GoogleConfigKey};
 
-    use super::*;
-
     #[tokio::test]
     async fn s3_object_store_builder() -> Result<()> {
         let access_key_id = "fake_access_key_id";
@@ -195,9 +195,7 @@ mod tests {
                 assert_eq!(value, builder.get_config_value(&key).unwrap());
             }
         } else {
-            return Err(DataFusionError::Plan(
-                "LogicalPlan is not a CreateExternalTable".to_string(),
-            ));
+            return plan_err!("LogicalPlan is not a CreateExternalTable");
         }
 
         Ok(())
@@ -228,9 +226,7 @@ mod tests {
                 assert_eq!(value, builder.get_config_value(&key).unwrap());
             }
         } else {
-            return Err(DataFusionError::Plan(
-                "LogicalPlan is not a CreateExternalTable".to_string(),
-            ));
+            return plan_err!("LogicalPlan is not a CreateExternalTable");
         }
 
         Ok(())
@@ -265,9 +261,7 @@ mod tests {
                 assert_eq!(value, builder.get_config_value(&key).unwrap());
             }
         } else {
-            return Err(DataFusionError::Plan(
-                "LogicalPlan is not a CreateExternalTable".to_string(),
-            ));
+            return plan_err!("LogicalPlan is not a CreateExternalTable");
         }
 
         Ok(())
