@@ -18,8 +18,9 @@
 //! Print format variants
 use arrow::csv::writer::WriterBuilder;
 use arrow::json::{ArrayWriter, LineDelimitedWriter};
+use arrow::util::pretty::pretty_format_batches_with_options;
 use datafusion::arrow::record_batch::RecordBatch;
-use datafusion::arrow::util::pretty;
+use datafusion::common::format::DEFAULT_FORMAT_OPTIONS;
 use datafusion::error::{DataFusionError, Result};
 use std::str::FromStr;
 
@@ -75,7 +76,12 @@ impl PrintFormat {
         match self {
             Self::Csv => println!("{}", print_batches_with_sep(batches, b',')?),
             Self::Tsv => println!("{}", print_batches_with_sep(batches, b'\t')?),
-            Self::Table => pretty::print_batches(batches)?,
+            Self::Table => {
+                println!(
+                    "{}",
+                    pretty_format_batches_with_options(batches, &DEFAULT_FORMAT_OPTIONS)?
+                )
+            }
             Self::Json => println!("{}", batches_to_json!(ArrayWriter, batches)),
             Self::NdJson => {
                 println!("{}", batches_to_json!(LineDelimitedWriter, batches))
