@@ -25,7 +25,7 @@ use arrow::datatypes::{DataType, Field, SchemaBuilder, SchemaRef};
 use arrow_schema::Schema;
 use async_trait::async_trait;
 use dashmap::DashMap;
-use datafusion_common::{plan_err, project_schema, SchemaExt, ToDFSchema};
+use datafusion_common::{internal_err, plan_err, project_schema, SchemaExt, ToDFSchema};
 use datafusion_expr::expr::Sort;
 use datafusion_optimizer::utils::conjunction;
 use datafusion_physical_expr::{create_physical_expr, LexOrdering, PhysicalSortExpr};
@@ -33,7 +33,6 @@ use futures::{future, stream, StreamExt, TryStreamExt};
 use object_store::path::Path;
 use object_store::ObjectMeta;
 
-use crate::datasource::file_format::file_type::{FileCompressionType, FileType};
 use crate::datasource::physical_plan::{FileScanConfig, FileSinkConfig};
 use crate::datasource::{
     file_format::{
@@ -52,6 +51,7 @@ use crate::{
     logical_expr::Expr,
     physical_plan::{empty::EmptyExec, ExecutionPlan, Statistics},
 };
+use datafusion_common::{FileCompressionType, FileType};
 
 use super::PartitionedFile;
 
@@ -195,9 +195,7 @@ impl ListingTableConfig {
                     options: Some(options),
                 })
             }
-            None => Err(DataFusionError::Internal(
-                "No `ListingOptions` set for inferring schema".into(),
-            )),
+            None => internal_err!("No `ListingOptions` set for inferring schema"),
         }
     }
 
@@ -217,6 +215,22 @@ pub enum ListingTableInsertMode {
     ///Throw an error if insert into is attempted on this table
     Error,
 }
+
+impl FromStr for ListingTableInsertMode {
+    type Err = DataFusionError;
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        let s_lower = s.to_lowercase();
+        match s_lower.as_str() {
+            "append_to_file" => Ok(ListingTableInsertMode::AppendToFile),
+            "append_new_files" => Ok(ListingTableInsertMode::AppendNewFiles),
+            "error" => Ok(ListingTableInsertMode::Error),
+            _ => Err(DataFusionError::Plan(format!(
+                "Unknown or unsupported insert mode {s}. Supported options are \
+                append_to_file, append_new_files, and error."
+            ))),
+        }
+    }
+}
 /// Options for creating a [`ListingTable`]
 #[derive(Clone, Debug)]
 pub struct ListingOptions {
@@ -845,10 +859,12 @@ impl TableProvider for ListingTable {
                         file_groups.len()
                     )));
                 }
-                writer_mode = crate::datasource::file_format::FileWriterMode::Append;
+                writer_mode =
+                    crate::datasource::file_format::write::FileWriterMode::Append;
             }
             ListingTableInsertMode::AppendNewFiles => {
-                writer_mode = crate::datasource::file_format::FileWriterMode::PutMultipart
+                writer_mode =
+                    crate::datasource::file_format::write::FileWriterMode::PutMultipart
             }
             ListingTableInsertMode::Error => {
                 return plan_err!(
@@ -865,6 +881,8 @@ impl TableProvider for ListingTable {
             output_schema: self.schema(),
             table_partition_cols: self.options.table_partition_cols.clone(),
             writer_mode,
+            // TODO: when listing table is known to be backed by a single file, this should be false
+            per_thread_output: true,
             overwrite,
         };
 
@@ -945,7 +963,6 @@ impl ListingTable {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::datasource::file_format::file_type::GetExt;
     use crate::datasource::{provider_as_source, MemTable};
     use crate::execution::options::ArrowReadOptions;
     use crate::physical_plan::collect;
@@ -961,8 +978,10 @@ mod tests {
     use arrow::record_batch::RecordBatch;
     use chrono::DateTime;
     use datafusion_common::assert_contains;
+    use datafusion_common::GetExt;
     use datafusion_expr::LogicalPlanBuilder;
     use rstest::*;
+    use std::collections::HashMap;
     use std::fs::File;
     use tempfile::TempDir;
 
@@ -1554,6 +1573,7 @@ mod tests {
         helper_test_insert_into_append_to_existing_files(
             FileType::JSON,
             FileCompressionType::UNCOMPRESSED,
+            None,
         )
         .await?;
         Ok(())
@@ -1564,6 +1584,7 @@ mod tests {
         helper_test_append_new_files_to_table(
             FileType::JSON,
             FileCompressionType::UNCOMPRESSED,
+            None,
         )
         .await?;
         Ok(())
@@ -1574,6 +1595,7 @@ mod tests {
         helper_test_insert_into_append_to_existing_files(
             FileType::CSV,
             FileCompressionType::UNCOMPRESSED,
+            None,
         )
         .await?;
         Ok(())
@@ -1584,11 +1606,245 @@ mod tests {
         helper_test_append_new_files_to_table(
             FileType::CSV,
             FileCompressionType::UNCOMPRESSED,
+            None,
         )
         .await?;
         Ok(())
     }
 
+    #[tokio::test]
+    async fn test_insert_into_append_new_parquet_files_defaults() -> Result<()> {
+        helper_test_append_new_files_to_table(
+            FileType::PARQUET,
+            FileCompressionType::UNCOMPRESSED,
+            None,
+        )
+        .await?;
+        Ok(())
+    }
+
+    #[tokio::test]
+    async fn test_insert_into_sql_csv_defaults() -> Result<()> {
+        helper_test_insert_into_sql(
+            "csv",
+            FileCompressionType::UNCOMPRESSED,
+            "OPTIONS (insert_mode 'append_new_files')",
+            None,
+        )
+        .await?;
+        Ok(())
+    }
+
+    #[tokio::test]
+    async fn test_insert_into_sql_csv_defaults_header_row() -> Result<()> {
+        helper_test_insert_into_sql(
+            "csv",
+            FileCompressionType::UNCOMPRESSED,
+            "WITH HEADER ROW \
+            OPTIONS (insert_mode 'append_new_files')",
+            None,
+        )
+        .await?;
+        Ok(())
+    }
+
+    #[tokio::test]
+    async fn test_insert_into_sql_json_defaults() -> Result<()> {
+        helper_test_insert_into_sql(
+            "json",
+            FileCompressionType::UNCOMPRESSED,
+            "OPTIONS (insert_mode 'append_new_files')",
+            None,
+        )
+        .await?;
+        Ok(())
+    }
+
+    #[tokio::test]
+    async fn test_insert_into_sql_parquet_defaults() -> Result<()> {
+        helper_test_insert_into_sql(
+            "parquet",
+            FileCompressionType::UNCOMPRESSED,
+            "",
+            None,
+        )
+        .await?;
+        Ok(())
+    }
+
+    #[tokio::test]
+    async fn test_insert_into_sql_parquet_session_overrides() -> Result<()> {
+        let mut config_map: HashMap<String, String> = HashMap::new();
+        config_map.insert(
+            "datafusion.execution.parquet.compression".into(),
+            "zstd(5)".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.dictionary_enabled".into(),
+            "false".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.dictionary_page_size_limit".into(),
+            "100".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.staistics_enabled".into(),
+            "none".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.max_statistics_size".into(),
+            "10".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.max_row_group_size".into(),
+            "5".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.created_by".into(),
+            "datafusion test".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.column_index_truncate_length".into(),
+            "50".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.data_page_row_count_limit".into(),
+            "50".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.bloom_filter_enabled".into(),
+            "true".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.bloom_filter_fpp".into(),
+            "0.01".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.bloom_filter_ndv".into(),
+            "1000".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.writer_version".into(),
+            "2.0".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.write_batch_size".into(),
+            "5".into(),
+        );
+        helper_test_insert_into_sql(
+            "parquet",
+            FileCompressionType::UNCOMPRESSED,
+            "",
+            Some(config_map),
+        )
+        .await?;
+        Ok(())
+    }
+
+    #[tokio::test]
+    async fn test_insert_into_append_new_parquet_files_session_overrides() -> Result<()> {
+        let mut config_map: HashMap<String, String> = HashMap::new();
+        config_map.insert(
+            "datafusion.execution.parquet.compression".into(),
+            "zstd(5)".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.dictionary_enabled".into(),
+            "false".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.dictionary_page_size_limit".into(),
+            "100".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.staistics_enabled".into(),
+            "none".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.max_statistics_size".into(),
+            "10".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.max_row_group_size".into(),
+            "5".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.created_by".into(),
+            "datafusion test".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.column_index_truncate_length".into(),
+            "50".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.data_page_row_count_limit".into(),
+            "50".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.encoding".into(),
+            "delta_binary_packed".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.bloom_filter_enabled".into(),
+            "true".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.bloom_filter_fpp".into(),
+            "0.01".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.bloom_filter_ndv".into(),
+            "1000".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.writer_version".into(),
+            "2.0".into(),
+        );
+        config_map.insert(
+            "datafusion.execution.parquet.write_batch_size".into(),
+            "5".into(),
+        );
+        helper_test_append_new_files_to_table(
+            FileType::PARQUET,
+            FileCompressionType::UNCOMPRESSED,
+            Some(config_map),
+        )
+        .await?;
+        Ok(())
+    }
+
+    #[tokio::test]
+    async fn test_insert_into_append_new_parquet_files_invalid_session_fails(
+    ) -> Result<()> {
+        let mut config_map: HashMap<String, String> = HashMap::new();
+        config_map.insert(
+            "datafusion.execution.parquet.compression".into(),
+            "zstd".into(),
+        );
+        let e = helper_test_append_new_files_to_table(
+            FileType::PARQUET,
+            FileCompressionType::UNCOMPRESSED,
+            Some(config_map),
+        )
+        .await
+        .expect_err("Example should fail!");
+        assert_eq!("Error during planning: zstd compression requires specifying a level such as zstd(4)", format!("{e}"));
+        Ok(())
+    }
+
+    #[tokio::test]
+    async fn test_insert_into_append_to_parquet_file_fails() -> Result<()> {
+        let maybe_err = helper_test_insert_into_append_to_existing_files(
+            FileType::PARQUET,
+            FileCompressionType::UNCOMPRESSED,
+            None,
+        )
+        .await;
+        let _err =
+            maybe_err.expect_err("Appending to existing parquet file did not fail!");
+        Ok(())
+    }
+
     fn load_empty_schema_table(
         schema: SchemaRef,
         temp_path: &str,
@@ -1615,9 +1871,16 @@ mod tests {
     async fn helper_test_insert_into_append_to_existing_files(
         file_type: FileType,
         file_compression_type: FileCompressionType,
+        session_config_map: Option<HashMap<String, String>>,
     ) -> Result<()> {
         // Create the initial context, schema, and batch.
-        let session_ctx = SessionContext::new();
+        let session_ctx = match session_config_map {
+            Some(cfg) => {
+                let config = SessionConfig::from_string_hash_map(cfg)?;
+                SessionContext::with_config(config)
+            }
+            None => SessionContext::new(),
+        };
         // Create a new schema with one field called "a" of type Int32
         let schema = Arc::new(Schema::new(vec![Field::new(
             "column1",
@@ -1777,9 +2040,17 @@ mod tests {
     async fn helper_test_append_new_files_to_table(
         file_type: FileType,
         file_compression_type: FileCompressionType,
+        session_config_map: Option<HashMap<String, String>>,
     ) -> Result<()> {
         // Create the initial context, schema, and batch.
-        let session_ctx = SessionContext::new();
+        let session_ctx = match session_config_map {
+            Some(cfg) => {
+                let config = SessionConfig::from_string_hash_map(cfg)?;
+                SessionContext::with_config(config)
+            }
+            None => SessionContext::new(),
+        };
+
         // Create a new schema with one field called "a" of type Int32
         let schema = Arc::new(Schema::new(vec![Field::new(
             "column1",
@@ -1825,9 +2096,9 @@ mod tests {
                     .register_parquet(
                         "t",
                         tmp_dir.path().to_str().unwrap(),
-                        ParquetReadOptions::default(), // TODO implement insert_mode for parquet
-                                                       //.insert_mode(ListingTableInsertMode::AppendNewFiles)
-                                                       //.schema(schema.as_ref()),
+                        ParquetReadOptions::default()
+                            .insert_mode(ListingTableInsertMode::AppendNewFiles)
+                            .schema(schema.as_ref()),
                     )
                     .await?;
             }
@@ -1894,16 +2165,16 @@ mod tests {
 
         // Read the records in the table
         let batches = session_ctx
-            .sql("select count(*) from t")
+            .sql("select count(*) as count from t")
             .await?
             .collect()
             .await?;
         let expected = vec![
-            "+----------+",
-            "| COUNT(*) |",
-            "+----------+",
-            "| 6        |",
-            "+----------+",
+            "+-------+",
+            "| count |",
+            "+-------+",
+            "| 6     |",
+            "+-------+",
         ];
 
         // Assert that the batches read from the file match the expected result.
@@ -1935,18 +2206,18 @@ mod tests {
 
         // Read the contents of the table
         let batches = session_ctx
-            .sql("select count(*) from t")
+            .sql("select count(*) AS count from t")
             .await?
             .collect()
             .await?;
 
         // Define the expected result after the second append.
         let expected = vec![
-            "+----------+",
-            "| COUNT(*) |",
-            "+----------+",
-            "| 12       |",
-            "+----------+",
+            "+-------+",
+            "| count |",
+            "+-------+",
+            "| 12    |",
+            "+-------+",
         ];
 
         // Assert that the batches read from the file after the second append match the expected result.
@@ -1959,4 +2230,64 @@ mod tests {
         // Return Ok if the function
         Ok(())
     }
+
+    /// tests insert into with end to end sql
+    /// create external table + insert into statements
+    async fn helper_test_insert_into_sql(
+        file_type: &str,
+        // TODO test with create statement options such as compression
+        _file_compression_type: FileCompressionType,
+        external_table_options: &str,
+        session_config_map: Option<HashMap<String, String>>,
+    ) -> Result<()> {
+        // Create the initial context
+        let session_ctx = match session_config_map {
+            Some(cfg) => {
+                let config = SessionConfig::from_string_hash_map(cfg)?;
+                SessionContext::with_config(config)
+            }
+            None => SessionContext::new(),
+        };
+
+        // create table
+        let tmp_dir = TempDir::new()?;
+        let tmp_path = tmp_dir.into_path();
+        let str_path = tmp_path.to_str().expect("Temp path should convert to &str");
+        session_ctx
+            .sql(&format!(
+                "create external table foo(a varchar, b varchar, c int) \
+                        stored as {file_type} \
+                        location '{str_path}' \
+                        {external_table_options}"
+            ))
+            .await?
+            .collect()
+            .await?;
+
+        // insert data
+        session_ctx.sql("insert into foo values ('foo', 'bar', 1),('foo', 'bar', 2), ('foo', 'bar', 3)")
+           .await?
+           .collect()
+           .await?;
+
+        // check count
+        let batches = session_ctx
+            .sql("select * from foo")
+            .await?
+            .collect()
+            .await?;
+
+        let expected = vec![
+            "+-----+-----+---+",
+            "| a   | b   | c |",
+            "+-----+-----+---+",
+            "| foo | bar | 1 |",
+            "| foo | bar | 2 |",
+            "| foo | bar | 3 |",
+            "+-----+-----+---+",
+        ];
+        assert_batches_eq!(expected, &batches);
+
+        Ok(())
+    }
 }
