@@ -30,12 +30,11 @@ pub mod optimizer;
 pub mod pipeline_checker;
 pub mod pruning;
 pub mod repartition;
-pub mod replace_repartition_execs;
+pub mod replace_with_order_preserving_variants;
 pub mod sort_enforcement;
 mod sort_pushdown;
 mod utils;
 
-pub mod pipeline_fixer;
 #[cfg(test)]
 pub mod test_utils;
 
