@@ -37,12 +37,11 @@ use arrow::compute::filter_record_batch;
 use arrow::datatypes::{DataType, SchemaRef};
 use arrow::record_batch::RecordBatch;
 use datafusion_common::cast::as_boolean_array;
-use datafusion_common::{DataFusionError, Result};
+use datafusion_common::{plan_err, DataFusionError, Result};
 use datafusion_execution::TaskContext;
 use datafusion_expr::Operator;
 use datafusion_physical_expr::expressions::BinaryExpr;
-use datafusion_physical_expr::intervals::is_operator_supported;
-use datafusion_physical_expr::utils::collect_columns;
+use datafusion_physical_expr::intervals::check_support;
 use datafusion_physical_expr::{
     analyze, split_conjunction, AnalysisContext, ExprBoundaries,
     OrderingEquivalenceProperties, PhysicalExpr,
@@ -75,9 +74,9 @@ impl FilterExec {
                 input: input.clone(),
                 metrics: ExecutionPlanMetricsSet::new(),
             }),
-            other => Err(DataFusionError::Plan(format!(
-                "Filter predicate must return boolean values, not {other:?}"
-            ))),
+            other => {
+                plan_err!("Filter predicate must return boolean values, not {other:?}")
+            }
         }
     }
 
@@ -191,11 +190,8 @@ impl ExecutionPlan for FilterExec {
     fn statistics(&self) -> Statistics {
         let predicate = self.predicate();
 
-        if let Some(binary) = predicate.as_any().downcast_ref::<BinaryExpr>() {
-            let columns = collect_columns(predicate);
-            if !is_operator_supported(binary.op()) || columns.is_empty() {
-                return Statistics::default();
-            }
+        if !check_support(predicate) {
+            return Statistics::default();
         }
 
         let input_stats = self.input.statistics();
@@ -385,7 +381,6 @@ mod tests {
     use crate::physical_plan::expressions::*;
     use crate::physical_plan::ExecutionPlan;
     use crate::physical_plan::{collect, with_new_children_if_necessary};
-    use crate::prelude::SessionContext;
     use crate::test;
     use crate::test::exec::StatisticsExec;
     use crate::test_util;
@@ -396,15 +391,16 @@ mod tests {
     use datafusion_expr::Operator;
     use std::iter::Iterator;
     use std::sync::Arc;
+    use tempfile::TempDir;
 
     #[tokio::test]
     async fn simple_predicate() -> Result<()> {
-        let session_ctx = SessionContext::new();
-        let task_ctx = session_ctx.task_ctx();
+        let task_ctx = Arc::new(TaskContext::default());
         let schema = test_util::aggr_test_schema();
 
         let partitions = 4;
-        let csv = test::scan_partitioned_csv(partitions)?;
+        let tmp_dir = TempDir::new()?;
+        let csv = test::scan_partitioned_csv(partitions, tmp_dir.path())?;
 
         let predicate: Arc<dyn PhysicalExpr> = binary(
             binary(col("c2", &schema)?, Operator::Gt, lit(1u32), &schema)?,
@@ -431,7 +427,8 @@ mod tests {
     async fn with_new_children() -> Result<()> {
         let schema = test_util::aggr_test_schema();
         let partitions = 4;
-        let input = test::scan_partitioned_csv(partitions)?;
+        let tmp_dir = TempDir::new()?;
+        let input = test::scan_partitioned_csv(partitions, tmp_dir.path())?;
 
         let predicate: Arc<dyn PhysicalExpr> =
             binary(col("c2", &schema)?, Operator::Gt, lit(1u32), &schema)?;
