@@ -19,8 +19,6 @@
 
 mod baseline;
 mod builder;
-mod composite;
-mod tracker;
 mod value;
 
 use parking_lot::Mutex;
@@ -35,8 +33,6 @@ use hashbrown::HashMap;
 // public exports
 pub use baseline::{BaselineMetrics, RecordOutput};
 pub use builder::MetricBuilder;
-pub use composite::CompositeMetricsSet;
-pub use tracker::MemTrackingMetrics;
 pub use value::{Count, Gauge, MetricValue, ScopedTimerGuard, Time, Timestamp};
 
 /// Something that tracks a value of interest (metric) of a DataFusion
