@@ -18,8 +18,8 @@
 //! Defines the unnest column plan for unnesting values in a column that contains a list
 //! type, conceptually is like joining each row with all the values in the list column.
 use arrow::array::{
-    new_null_array, Array, ArrayAccessor, ArrayRef, ArrowPrimitiveType,
-    FixedSizeListArray, Int32Array, LargeListArray, ListArray, PrimitiveArray,
+    new_empty_array, new_null_array, Array, ArrayAccessor, ArrayRef, ArrowPrimitiveType,
+    FixedSizeListArray, LargeListArray, ListArray, PrimitiveArray,
 };
 use arrow::compute::kernels;
 use arrow::datatypes::{
@@ -28,7 +28,9 @@ use arrow::datatypes::{
 use arrow::record_batch::RecordBatch;
 use async_trait::async_trait;
 use datafusion_common::UnnestOptions;
-use datafusion_common::{cast::as_primitive_array, DataFusionError, Result};
+use datafusion_common::{
+    cast::as_primitive_array, not_impl_err, DataFusionError, Result,
+};
 use datafusion_execution::TaskContext;
 use futures::Stream;
 use futures::StreamExt;
@@ -147,9 +149,7 @@ impl ExecutionPlan for UnnestExec {
         let input = self.input.execute(partition, context)?;
 
         if !self.options.preserve_nulls {
-            return Err(DataFusionError::NotImplemented(
-                "Unnest with preserve_nulls=false".to_string(),
-            ));
+            return not_impl_err!("Unnest with preserve_nulls=false");
         }
 
         Ok(Box::pin(UnnestStream {
@@ -307,7 +307,7 @@ where
     //   1, null, 3, null, 2
     //
     // Depending on the list type the result may be Int32Array or Int64Array.
-    let list_lengths = list_lengths(list_array)?;
+    let list_lengths = kernels::length::length(list_array)?;
 
     // Create the indices for the take kernel and then use those indices to create
     // the unnested record batch.
@@ -459,6 +459,10 @@ where
         }
     };
 
+    if list_array.is_empty() {
+        return Ok(new_empty_array(elem_type));
+    }
+
     let null_row = new_null_array(elem_type, 1);
 
     // Create a vec of ArrayRef from the list elements.
@@ -478,33 +482,3 @@ where
 
     Ok(kernels::concat::concat(&arrays)?)
 }
-
-/// Returns an array with the lengths of each list in `list_array`. Returns null
-/// for a null value.
-fn list_lengths<T>(list_array: &T) -> Result<Arc<dyn Array + 'static>>
-where
-    T: ArrayAccessor<Item = ArrayRef>,
-{
-    match list_array.data_type() {
-        DataType::List(_) | DataType::LargeList(_) => {
-            Ok(kernels::length::length(list_array)?)
-        }
-        DataType::FixedSizeList(_, size) => {
-            // Handle FixedSizeList as it is not handled by the `length` kernel.
-            // https://github.com/apache/arrow-rs/issues/4517
-            let mut lengths = Vec::with_capacity(list_array.len());
-            for row in 0..list_array.len() {
-                if list_array.is_null(row) {
-                    lengths.push(None)
-                } else {
-                    lengths.push(Some(*size));
-                }
-            }
-
-            Ok(Arc::new(Int32Array::from(lengths)))
-        }
-        dt => Err(DataFusionError::Execution(format!(
-            "Invalid type {dt} for list_lengths"
-        ))),
-    }
-}
