@@ -20,10 +20,27 @@ use std::{
     sync::Arc,
 };
 
-use datafusion_common::{DFSchemaRef, OwnedTableReference};
+use datafusion_common::{DFSchemaRef, FileType, OwnedTableReference};
 
 use crate::LogicalPlan;
 
+/// Operator that copies the contents of a database to file(s)
+#[derive(Clone, PartialEq, Eq, Hash)]
+pub struct CopyTo {
+    /// The relation that determines the tuples to write to the output file(s)
+    pub input: Arc<LogicalPlan>,
+    /// The location to write the file(s)
+    pub output_url: String,
+    /// The file format to output (explicitly defined or inferred from file extension)
+    pub file_format: FileType,
+    /// If false, it is assumed output_url is a file to which all data should be written
+    /// regardless of input partitioning. Otherwise, output_url is assumed to be a directory
+    /// to which each output partition is written to its own output file
+    pub per_thread_output: bool,
+    /// Arbitrary options as tuples
+    pub options: Vec<(String, String)>,
+}
+
 /// The operator that modifies the content of a database (adapted from
 /// substrait WriteRel)
 #[derive(Clone, PartialEq, Eq, Hash)]
