@@ -100,10 +100,15 @@ pub use crate::PhysicalSortExpr;
 
 #[cfg(test)]
 pub(crate) mod tests {
+    use crate::expressions::{col, create_aggregate_expr, try_cast};
     use crate::AggregateExpr;
     use arrow::record_batch::RecordBatch;
+    use arrow_array::ArrayRef;
+    use arrow_schema::{Field, Schema};
     use datafusion_common::Result;
     use datafusion_common::ScalarValue;
+    use datafusion_expr::type_coercion::aggregates::coerce_types;
+    use datafusion_expr::AggregateFunction;
     use std::sync::Arc;
 
     /// macro to perform an aggregation and verify the result.
@@ -131,6 +136,36 @@ pub(crate) mod tests {
         }};
     }
 
+    /// Assert `function(array) == expected` performing any necessary type coercion
+    pub fn assert_aggregate(
+        array: ArrayRef,
+        function: AggregateFunction,
+        expected: ScalarValue,
+    ) {
+        let data_type = array.data_type();
+        let sig = function.signature();
+        let coerced = coerce_types(&function, &[data_type.clone()], &sig).unwrap();
+
+        let input_schema = Schema::new(vec![Field::new("a", data_type.clone(), true)]);
+        let batch =
+            RecordBatch::try_new(Arc::new(input_schema.clone()), vec![array]).unwrap();
+
+        let input = try_cast(
+            col("a", &input_schema).unwrap(),
+            &input_schema,
+            coerced[0].clone(),
+        )
+        .unwrap();
+
+        let schema = Schema::new(vec![Field::new("a", coerced[0].clone(), true)]);
+        let agg =
+            create_aggregate_expr(&function, false, &[input], &[], &schema, "aggregate")
+                .unwrap();
+
+        let result = aggregate(&batch, agg).unwrap();
+        assert_eq!(expected, result);
+    }
+
     /// macro to perform an aggregation with two inputs and verify the result.
     #[macro_export]
     macro_rules! generic_test_op2 {
