@@ -26,7 +26,9 @@ use crate::physical_expr::down_cast_any_ref;
 use crate::PhysicalExpr;
 use arrow::datatypes::{DataType, Schema};
 use arrow::record_batch::RecordBatch;
-use datafusion_common::{cast::as_boolean_array, DataFusionError, Result, ScalarValue};
+use datafusion_common::{
+    cast::as_boolean_array, internal_err, DataFusionError, Result, ScalarValue,
+};
 use datafusion_expr::ColumnarValue;
 
 /// Not expression
@@ -83,10 +85,10 @@ impl PhysicalExpr for NotExpr {
                 }
                 let value_type = scalar.get_datatype();
                 if value_type != DataType::Boolean {
-                    return Err(DataFusionError::Internal(format!(
+                    return internal_err!(
                         "NOT '{:?}' can't be evaluated because the expression's type is {:?}, not boolean or NULL",
-                        self.arg, value_type,
-                    )));
+                        self.arg, value_type
+                    );
                 }
                 let bool_value: bool = scalar.try_into()?;
                 Ok(ColumnarValue::Scalar(ScalarValue::Boolean(Some(
