@@ -69,6 +69,6 @@ pub use sort_expr::{
 };
 pub use utils::{
     expr_list_eq_any_order, expr_list_eq_strict_order,
-    normalize_expr_with_equivalence_properties, normalize_out_expr_with_columns_map,
-    reverse_order_bys, split_conjunction,
+    normalize_expr_with_equivalence_properties, normalize_ordering_equivalence_classes,
+    normalize_out_expr_with_columns_map, reverse_order_bys, split_conjunction,
 };
