@@ -18,6 +18,7 @@
 use std::{collections::HashSet, sync::Arc};
 
 use datafusion::execution::registry::FunctionRegistry;
+use datafusion_common::plan_err;
 use datafusion_common::{DataFusionError, Result};
 use datafusion_expr::{AggregateUDF, ScalarUDF, WindowUDF};
 
@@ -31,20 +32,14 @@ impl FunctionRegistry for NoRegistry {
     }
 
     fn udf(&self, name: &str) -> Result<Arc<ScalarUDF>> {
-        Err(DataFusionError::Plan(
-            format!("No function registry provided to deserialize, so can not deserialize User Defined Function '{name}'"))
-        )
+        plan_err!("No function registry provided to deserialize, so can not deserialize User Defined Function '{name}'")
     }
 
     fn udaf(&self, name: &str) -> Result<Arc<AggregateUDF>> {
-        Err(DataFusionError::Plan(
-            format!("No function registry provided to deserialize, so can not deserialize User Defined Aggregate Function '{name}'"))
-        )
+        plan_err!("No function registry provided to deserialize, so can not deserialize User Defined Aggregate Function '{name}'")
     }
 
     fn udwf(&self, name: &str) -> Result<Arc<WindowUDF>> {
-        Err(DataFusionError::Plan(
-            format!("No function registry provided to deserialize, so can not deserialize User Defined Window Function '{name}'"))
-        )
+        plan_err!("No function registry provided to deserialize, so can not deserialize User Defined Window Function '{name}'")
     }
 }
