@@ -17,7 +17,7 @@
 
 use crate::planner::{ContextProvider, PlannerContext, SqlToRel};
 use datafusion_common::{
-    Column, DFField, DFSchema, DataFusionError, Result, TableReference,
+    internal_err, Column, DFField, DFSchema, DataFusionError, Result, TableReference,
 };
 use datafusion_expr::{Case, Expr};
 use sqlparser::ast::{Expr as SQLExpr, Ident};
@@ -90,9 +90,7 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
         planner_context: &mut PlannerContext,
     ) -> Result<Expr> {
         if ids.len() < 2 {
-            return Err(DataFusionError::Internal(format!(
-                "Not a compound identifier: {ids:?}"
-            )));
+            return internal_err!("Not a compound identifier: {ids:?}");
         }
 
         if ids[0].value.starts_with('@') {
@@ -119,9 +117,7 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
             // Though ideally once that support is in place, this code should work with it
             // TODO: remove when can support multiple nested identifiers
             if ids.len() > 5 {
-                return Err(DataFusionError::Internal(format!(
-                    "Unsupported compound identifier: {ids:?}"
-                )));
+                return internal_err!("Unsupported compound identifier: {ids:?}");
             }
 
             let search_result = search_dfschema(&ids, schema);
@@ -130,10 +126,10 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                 Some((field, nested_names)) if !nested_names.is_empty() => {
                     // TODO: remove when can support multiple nested identifiers
                     if nested_names.len() > 1 {
-                        return Err(DataFusionError::Internal(format!(
+                        return internal_err!(
                             "Nested identifiers not yet supported for column {}",
                             field.qualified_column().quoted_flat_name()
-                        )));
+                        );
                     }
                     let nested_name = nested_names[0].to_string();
                     Ok(Expr::Column(field.qualified_column()).field(nested_name))
@@ -146,9 +142,7 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                     // return default where use all identifiers to not have a nested field
                     // this len check is because at 5 identifiers will have to have a nested field
                     if ids.len() == 5 {
-                        Err(DataFusionError::Internal(format!(
-                            "Unsupported compound identifier: {ids:?}"
-                        )))
+                        internal_err!("Unsupported compound identifier: {ids:?}")
                     } else {
                         // check the outer_query_schema and try to find a match
                         if let Some(outer) = planner_context.outer_query_schema() {
@@ -159,10 +153,10 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                                     if !nested_names.is_empty() =>
                                 {
                                     // TODO: remove when can support nested identifiers for OuterReferenceColumn
-                                    Err(DataFusionError::Internal(format!(
+                                    internal_err!(
                                         "Nested identifiers are not yet supported for OuterReferenceColumn {}",
                                         field.qualified_column().quoted_flat_name()
-                                    )))
+                                    )
                                 }
                                 // found matching field with no spare identifier(s)
                                 Some((field, _nested_names)) => {
@@ -269,10 +263,7 @@ fn form_identifier(idents: &[String]) -> Result<(Option<TableReference>, &String
             }),
             &idents[3],
         )),
-        _ => Err(DataFusionError::Internal(format!(
-            "Incorrect number of identifiers: {}",
-            idents.len()
-        ))),
+        _ => internal_err!("Incorrect number of identifiers: {}", idents.len()),
     }
 }
 
