@@ -16,6 +16,7 @@
 // under the License.
 
 use crate::planner::{ContextProvider, PlannerContext, SqlToRel};
+use datafusion_common::plan_err;
 use datafusion_common::{DFSchema, DataFusionError, Result, ScalarValue};
 use datafusion_expr::expr::ScalarFunction;
 use datafusion_expr::{BuiltinScalarFunction, Expr};
@@ -62,9 +63,7 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                     substring_for: None,
                 };
 
-                return Err(DataFusionError::Plan(format!(
-                    "Substring without for/from is not valid {orig_sql:?}"
-                )));
+                return plan_err!("Substring without for/from is not valid {orig_sql:?}");
             }
         };
 
