@@ -16,7 +16,7 @@
 // under the License.
 
 use crate::planner::{ContextProvider, PlannerContext, SqlToRel};
-use datafusion_common::{DataFusionError, Result};
+use datafusion_common::{not_impl_err, DataFusionError, Result};
 use datafusion_expr::{LogicalPlan, LogicalPlanBuilder};
 use sqlparser::ast::{SetExpr, SetOperator, SetQuantifier};
 
@@ -39,14 +39,10 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                     SetQuantifier::All => true,
                     SetQuantifier::Distinct | SetQuantifier::None => false,
                     SetQuantifier::ByName => {
-                        return Err(DataFusionError::NotImplemented(
-                            "UNION BY NAME not implemented".to_string(),
-                        ));
+                        return not_impl_err!("UNION BY NAME not implemented");
                     }
                     SetQuantifier::AllByName => {
-                        return Err(DataFusionError::NotImplemented(
-                            "UNION ALL BY NAME not implemented".to_string(),
-                        ))
+                        return not_impl_err!("UNION ALL BY NAME not implemented")
                     }
                 };
 
@@ -74,9 +70,7 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                 }
             }
             SetExpr::Query(q) => self.query_to_plan(*q, planner_context),
-            _ => Err(DataFusionError::NotImplemented(format!(
-                "Query {set_expr} not implemented yet"
-            ))),
+            _ => not_impl_err!("Query {set_expr} not implemented yet"),
         }
     }
 }
