@@ -16,8 +16,8 @@
 // under the License.
 
 use crate::parser::{
-    CopyToStatement, CreateExternalTable, DFParser, DescribeTableStmt, LexOrdering,
-    Statement as DFStatement,
+    CopyToSource, CopyToStatement, CreateExternalTable, DFParser, DescribeTableStmt,
+    ExplainStatement, LexOrdering, Statement as DFStatement,
 };
 use crate::planner::{
     object_name_to_qualifier, ContextProvider, PlannerContext, SqlToRel,
@@ -27,10 +27,11 @@ use crate::utils::normalize_ident;
 use arrow_schema::DataType;
 use datafusion_common::parsers::CompressionTypeVariant;
 use datafusion_common::{
-    unqualified_field_not_found, Column, Constraints, DFField, DFSchema, DFSchemaRef,
-    DataFusionError, ExprSchema, OwnedTableReference, Result, SchemaReference,
-    TableReference, ToDFSchema,
+    not_impl_err, unqualified_field_not_found, Column, Constraints, DFField, DFSchema,
+    DFSchemaRef, DataFusionError, ExprSchema, FileType, OwnedTableReference, Result,
+    SchemaReference, TableReference, ToDFSchema,
 };
+use datafusion_expr::dml::CopyTo;
 use datafusion_expr::expr::Placeholder;
 use datafusion_expr::expr_rewriter::normalize_col_with_schemas_and_ambiguity_check;
 use datafusion_expr::logical_plan::builder::project;
@@ -55,6 +56,8 @@ use sqlparser::parser::ParserError::ParserError;
 
 use datafusion_common::plan_err;
 use std::collections::{BTreeMap, HashMap, HashSet};
+use std::path::Path;
+use std::str::FromStr;
 use std::sync::Arc;
 
 fn ident_to_string(ident: &Ident) -> String {
@@ -90,16 +93,32 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
             DFStatement::Statement(s) => self.sql_statement_to_plan(*s),
             DFStatement::DescribeTableStmt(s) => self.describe_table_to_plan(s),
             DFStatement::CopyTo(s) => self.copy_to_plan(s),
+            DFStatement::Explain(ExplainStatement {
+                verbose,
+                analyze,
+                statement,
+            }) => self.explain_to_plan(verbose, analyze, *statement),
         }
     }
 
     /// Generate a logical plan from an SQL statement
     pub fn sql_statement_to_plan(&self, statement: Statement) -> Result<LogicalPlan> {
-        self.sql_statement_to_plan_with_context(statement, &mut PlannerContext::new())
+        self.sql_statement_to_plan_with_context_impl(
+            statement,
+            &mut PlannerContext::new(),
+        )
     }
 
     /// Generate a logical plan from an SQL statement
-    fn sql_statement_to_plan_with_context(
+    pub fn sql_statement_to_plan_with_context(
+        &self,
+        statement: Statement,
+        planner_context: &mut PlannerContext,
+    ) -> Result<LogicalPlan> {
+        self.sql_statement_to_plan_with_context_impl(statement, planner_context)
+    }
+
+    fn sql_statement_to_plan_with_context_impl(
         &self,
         statement: Statement,
         planner_context: &mut PlannerContext,
@@ -113,7 +132,9 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                 format: _,
                 describe_alias: _,
                 ..
-            } => self.explain_statement_to_plan(verbose, analyze, *statement),
+            } => {
+                self.explain_to_plan(verbose, analyze, DFStatement::Statement(statement))
+            }
             Statement::Query(query) => self.query_to_plan(*query, planner_context),
             Statement::ShowVariable { variable } => self.show_variable_to_plan(&variable),
             Statement::SetVariable {
@@ -223,9 +244,9 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
             }
             Statement::ShowCreate { obj_type, obj_name } => match obj_type {
                 ShowCreateObject::Table => self.show_create_table_to_plan(obj_name),
-                _ => Err(DataFusionError::NotImplemented(
-                    "Only `SHOW CREATE TABLE  ...` statement is supported".to_string(),
-                )),
+                _ => {
+                    not_impl_err!("Only `SHOW CREATE TABLE  ...` statement is supported")
+                }
             },
             Statement::CreateSchema {
                 schema_name,
@@ -296,10 +317,9 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                             cascade,
                             schema: DFSchemaRef::new(DFSchema::empty()),
                         })))},
-                    _ => Err(DataFusionError::NotImplemented(
+                    _ => not_impl_err!(
                         "Only `DROP TABLE/VIEW/SCHEMA  ...` statement is supported currently"
-                            .to_string(),
-                    )),
+                    ),
                 }
             }
             Statement::Prepare {
@@ -318,7 +338,7 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                     .with_prepare_param_data_types(data_types.clone());
 
                 // Build logical plan for inner statement of the prepare statement
-                let plan = self.sql_statement_to_plan_with_context(
+                let plan = self.sql_statement_to_plan_with_context_impl(
                     *statement,
                     &mut planner_context,
                 )?;
@@ -377,7 +397,6 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                 let _ = into; // optional keyword doesn't change behavior
                 self.insert_to_plan(table_name, columns, source, overwrite)
             }
-
             Statement::Update {
                 table,
                 assignments,
@@ -478,29 +497,25 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
                 Ok(LogicalPlan::Statement(statement))
             }
 
-            _ => Err(DataFusionError::NotImplemented(format!(
-                "Unsupported SQL statement: {sql:?}"
-            ))),
+            _ => not_impl_err!("Unsupported SQL statement: {sql:?}"),
         }
     }
 
     fn get_delete_target(&self, mut from: Vec<TableWithJoins>) -> Result<ObjectName> {
         if from.len() != 1 {
-            return Err(DataFusionError::NotImplemented(format!(
+            return not_impl_err!(
                 "DELETE FROM only supports single table, got {}: {from:?}",
                 from.len()
-            )));
+            );
         }
         let table_factor = from.pop().unwrap();
         if !table_factor.joins.is_empty() {
-            return Err(DataFusionError::NotImplemented(
-                "DELETE FROM only supports single table, got: joins".to_string(),
-            ));
+            return not_impl_err!("DELETE FROM only supports single table, got: joins");
         }
         let TableFactor::Table{name, ..} = table_factor.relation else {
-            return Err(DataFusionError::NotImplemented(format!(
+            return not_impl_err!(
                 "DELETE FROM only supports single table, got: {table_factor:?}"
-            )))
+            )
         };
 
         Ok(name)
@@ -547,11 +562,71 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
         }))
     }
 
-    fn copy_to_plan(&self, _statement: CopyToStatement) -> Result<LogicalPlan> {
-        // TODO: implement as part of https://github.com/apache/arrow-datafusion/issues/5654
-        Err(DataFusionError::NotImplemented(
-            "`COPY .. TO ..` statement is not yet supported".to_string(),
-        ))
+    fn copy_to_plan(&self, statement: CopyToStatement) -> Result<LogicalPlan> {
+        // determine if source is table or query and handle accordingly
+        let copy_source = statement.source;
+        let input = match copy_source {
+            CopyToSource::Relation(object_name) => {
+                let table_ref =
+                    self.object_name_to_table_reference(object_name.clone())?;
+                let table_source = self.schema_provider.get_table_provider(table_ref)?;
+                LogicalPlanBuilder::scan(
+                    object_name_to_string(&object_name),
+                    table_source,
+                    None,
+                )?
+                .build()?
+            }
+            CopyToSource::Query(query) => {
+                self.query_to_plan(query, &mut PlannerContext::new())?
+            }
+        };
+
+        // convert options to lowercase strings, check for explicitly set "format" option
+        let mut options = vec![];
+        let mut explicit_format = None;
+        // default behavior is to assume the user is specifying a single file to which
+        // we should output all data regardless of input partitioning.
+        let mut per_thread_output: bool = false;
+        for (key, value) in statement.options {
+            let (k, v) = (key.to_lowercase(), value.to_string().to_lowercase());
+            // check for options important to planning
+            if k == "format" {
+                explicit_format = Some(FileType::from_str(&v)?);
+            }
+            if k == "per_thread_output" {
+                per_thread_output = match v.as_str(){
+                    "true" => true,
+                    "false" => false,
+                    _ => return Err(DataFusionError::Plan(
+                        format!("Copy to option 'per_thread_output' must be true or false, got {value}")
+                    ))
+                }
+            }
+            options.push((k, v));
+        }
+        let format = match explicit_format {
+            Some(file_format) => file_format,
+            None => {
+                // try to infer file format from file extension
+                let extension: &str = &Path::new(&statement.target)
+                    .extension()
+                    .ok_or(
+                        DataFusionError::Plan("Copy To format not explicitly set and unable to get file extension!".to_string()))?
+                    .to_str()
+                    .ok_or(DataFusionError::Plan("Copy to format not explicitly set and failed to parse file extension!".to_string()))?
+                    .to_lowercase();
+
+                FileType::from_str(extension)?
+            }
+        };
+        Ok(LogicalPlan::Copy(CopyTo {
+            input: Arc::new(input),
+            output_url: statement.target,
+            file_format: format,
+            per_thread_output,
+            options,
+        }))
     }
 
     fn build_order_by(
@@ -607,11 +682,6 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
             options,
         } = statement;
 
-        // semantic checks
-        if file_type == "PARQUET" && !columns.is_empty() {
-            plan_err!("Column definitions can not be specified for PARQUET files.")?;
-        }
-
         if file_type != "CSV"
             && file_type != "JSON"
             && file_compression_type != CompressionTypeVariant::UNCOMPRESSED
@@ -649,13 +719,18 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
 
     /// Generate a plan for EXPLAIN ... that will print out a plan
     ///
-    fn explain_statement_to_plan(
+    /// Note this is the sqlparser explain statement, not the
+    /// datafusion `EXPLAIN` statement.
+    fn explain_to_plan(
         &self,
         verbose: bool,
         analyze: bool,
-        statement: Statement,
+        statement: DFStatement,
     ) -> Result<LogicalPlan> {
-        let plan = self.sql_statement_to_plan(statement)?;
+        let plan = self.statement_to_plan(statement)?;
+        if matches!(plan, LogicalPlan::Explain(_)) {
+            return plan_err!("Nested EXPLAINs are not supported");
+        }
         let plan = Arc::new(plan);
         let schema = LogicalPlan::explain_schema();
         let schema = schema.to_dfschema_ref()?;
@@ -718,15 +793,11 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
         value: Vec<sqlparser::ast::Expr>,
     ) -> Result<LogicalPlan> {
         if local {
-            return Err(DataFusionError::NotImplemented(
-                "LOCAL is not supported".to_string(),
-            ));
+            return not_impl_err!("LOCAL is not supported");
         }
 
         if hivevar {
-            return Err(DataFusionError::NotImplemented(
-                "HIVEVAR is not supported".to_string(),
-            ));
+            return not_impl_err!("HIVEVAR is not supported");
         }
 
         let variable = object_name_to_string(variable);
@@ -838,7 +909,10 @@ impl<'a, S: ContextProvider> SqlToRel<'a, S> {
             .schema_provider
             .get_table_provider(table_name.clone())?;
         let arrow_schema = (*provider.schema()).clone();
-        let table_schema = Arc::new(DFSchema::try_from(arrow_schema)?);
+        let table_schema = Arc::new(DFSchema::try_from_qualified_schema(
+            table_name.clone(),
+            &arrow_schema,
+        )?);
         let values = table_schema.fields().iter().map(|f| {
             (
                 f.name().clone(),
